@@ -36,7 +36,7 @@
 #define XAPIAN_ENABLE_VISIBILITY
 
 /// The version of Xapian as a C string literal.
-#define XAPIAN_VERSION "1.4.30"
+#define XAPIAN_VERSION "1.4.31"
 
 /** The major component of the Xapian version.
  * E.g. for Xapian 1.0.14 this would be: 1
@@ -51,7 +51,7 @@
 /** The revision component of the Xapian version.
  * E.g. for Xapian 1.0.14 this would be: 14
  */
-#define XAPIAN_REVISION 30
+#define XAPIAN_REVISION 31
 
 /// Base (signed) type for Xapian::docid and related types.
 #define XAPIAN_DOCID_BASE_TYPE int
@@ -63,10 +63,10 @@
 #define XAPIAN_TERMPOS_BASE_TYPE int
 
 /// Type for returning total document length.
-#define XAPIAN_TOTALLENGTH_TYPE unsigned long
+#define XAPIAN_TOTALLENGTH_TYPE unsigned long long
 
 /// Underlying type for Xapian::rev.
-#define XAPIAN_REVISION_TYPE unsigned long
+#define XAPIAN_REVISION_TYPE unsigned long long
 
 /// XAPIAN_HAS_CHERT_BACKEND Defined if the chert backend is enabled.
 #define XAPIAN_HAS_CHERT_BACKEND 1
@@ -88,7 +88,23 @@
 /// #endif
 /// @endcode
 ///
-/// Added in Xapian 1.4.2.
+/// XAPIAN_AT_LEAST was added in Xapian 1.4.2. This was released 2016-12-26
+/// so is now a reasonable hard requirement.
+///
+/// If you really want to support older versions beware that a check like:
+///
+/// #if defined XAPIAN_AT_LEAST && XAPIAN_AT_LEAST(1,4,12)
+///
+/// works with newer Xapian but fails to compile if the macro is not
+/// defined:
+///
+/// error: missing binary operator before token ‘(’
+///
+/// In this situation we recommend copying the definition of XAPIAN_AT_LEAST
+/// into your code and wrapping it in `#ifndef XAPIAN_AT_LEAST` ... `#endif`
+/// so you can use it unconditionally.
+///
+/// @since Xapian 1.4.2.
 #define XAPIAN_AT_LEAST(A,B,C) \
  (XAPIAN_MAJOR_VERSION > (A) || \
  (XAPIAN_MAJOR_VERSION == (A) && \
